(defvar Pk_VoidSymbol 0xFFFFFF t)
(defvar Pk_InvalidSymbol (bnot 0) t)
(defvar Pk_OEM_KeyCap 0x80000000 t)
(defvar Pk_KF_Key_Down 0x00000001 t)
(defvar Pk_KF_Key_Repeat 0x00000002 t)
(defvar Pk_KF_Scan_Valid 0x00000020 t)
(defvar Pk_KF_Sym_Valid 0x00000040 t)
(defvar Pk_KF_Cap_Valid 0x00000080 t)
(defvar Pk_KF_Fep_Kick 0x20000000 t)
(defvar Pk_KF_Compose 0x40000000 t)
(defvar Pk_KM_Shift 0x00000001 t)
(defvar Pk_KM_Ctrl 0x00000002 t)
(defvar Pk_KM_Alt 0x00000004 t)
(defvar Pk_KM_AltGr 0x00000008 t)
(defvar Pk_KM_Shl3 0x00000010 t)
(defvar Pk_KM_Mod6 0x00000020 t)
(defvar Pk_KM_Mod7 0x00000040 t)
(defvar Pk_KM_Mod8 0x00000080 t)
(defvar Pk_KM_Shift_Lock 0x00000100 t)
(defvar Pk_KM_Ctrl_Lock 0x00000200 t)
(defvar Pk_KM_Alt_Lock 0x00000400 t)
(defvar Pk_KM_AltGr_Lock 0x00000800 t)
(defvar Pk_KM_Shl3_Lock 0x00001000 t)
(defvar Pk_KM_Mod6_Lock 0x00002000 t)
(defvar Pk_KM_Mod7_Lock 0x00004000 t)
(defvar Pk_KM_Mod8_Lock 0x00008000 t)
(defvar Pk_KM_Caps_Lock 0x00010000 t)
(defvar Pk_KM_Num_Lock 0x00020000 t)
(defvar Pk_KM_Scroll_Lock 0x00040000 t)
(defvar Pk_BackSpace 0xF008 t)
(defvar Pk_Tab 0xF009 t)
(defvar Pk_Linefeed 0xF00A t)
(defvar Pk_Clear 0xF00B t)
(defvar Pk_Return 0xF00D t)
(defvar Pk_Pause 0xF013 t)
(defvar Pk_Scroll_Lock 0xF014 t)
(defvar Pk_Escape 0xF01B t)
(defvar Pk_Delete 0xF0FF t)
(defvar Pk_Multi_key 0xF020 t)
(defvar Pk_Kanji 0xF021 t)
(defvar Pk_Muhenkan 0xF022 t)
(defvar Pk_Henkan_Mode 0xF023 t)
(defvar Pk_Henkan 0xF023 t)
(defvar Pk_Romaji 0xF024 t)
(defvar Pk_Hiragana 0xF025 t)
(defvar Pk_Katakana 0xF026 t)
(defvar Pk_Hiragana_Katakana 0xF027 t)
(defvar Pk_Zenkaku 0xF028 t)
(defvar Pk_Hankaku 0xF029 t)
(defvar Pk_Zenkaku_Hankaku 0xF02A t)
(defvar Pk_Touroku 0xF02B t)
(defvar Pk_Massyo 0xF02C t)
(defvar Pk_Kana_Lock 0xF02D t)
(defvar Pk_Kana_Shift 0xF02E t)
(defvar Pk_Eisu_Shift 0xF02F t)
(defvar Pk_Eisu_toggle 0xF030 t)
(defvar Pk_Home 0xF050 t)
(defvar Pk_Left 0xF051 t)
(defvar Pk_Up 0xF052 t)
(defvar Pk_Right 0xF053 t)
(defvar Pk_Down 0xF054 t)
(defvar Pk_Prior 0xF055 t)
(defvar Pk_Pg_Up 0xF055 t)
(defvar Pk_Next 0xF056 t)
(defvar Pk_Pg_Down 0xF056 t)
(defvar Pk_End 0xF057 t)
(defvar Pk_Begin 0xF058 t)
(defvar Pk_Select 0xF060 t)
(defvar Pk_Print 0xF061 t)
(defvar Pk_Execute 0xF062 t)
(defvar Pk_Insert 0xF063 t)
(defvar Pk_Undo 0xF065 t)
(defvar Pk_Redo 0xF066 t)
(defvar Pk_Menu 0xF067 t)
(defvar Pk_Find 0xF068 t)
(defvar Pk_Cancel 0xF069 t)
(defvar Pk_Help 0xF06A t)
(defvar Pk_Break 0xF06B t)
(defvar Pk_Mode_switch 0xF07E t)
(defvar Pk_script_switch 0xF07E t)
(defvar Pk_Num_Lock 0xF07F t)
(defvar Pk_KP_Space 0xF080 t)
(defvar Pk_KP_Tab 0xF089 t)
(defvar Pk_KP_Enter 0xF08D t)
(defvar Pk_KP_F1 0xF091 t)
(defvar Pk_KP_F2 0xF092 t)
(defvar Pk_KP_F3 0xF093 t)
(defvar Pk_KP_F4 0xF094 t)
(defvar Pk_KP_Equal 0xF0BD t)
(defvar Pk_KP_Multiply 0xF0AA t)
(defvar Pk_KP_Add 0xF0AB t)
(defvar Pk_KP_Separator 0xF0AC t)
(defvar Pk_KP_Subtract 0xF0AD t)
(defvar Pk_KP_Decimal 0xF0AE t)
(defvar Pk_KP_Divide 0xF0AF t)
(defvar Pk_KP_0 0xF0B0 t)
(defvar Pk_KP_1 0xF0B1 t)
(defvar Pk_KP_2 0xF0B2 t)
(defvar Pk_KP_3 0xF0B3 t)
(defvar Pk_KP_4 0xF0B4 t)
(defvar Pk_KP_5 0xF0B5 t)
(defvar Pk_KP_6 0xF0B6 t)
(defvar Pk_KP_7 0xF0B7 t)
(defvar Pk_KP_8 0xF0B8 t)
(defvar Pk_KP_9 0xF0B9 t)
(defvar Pk_F1 0xF0BE t)
(defvar Pk_F2 0xF0BF t)
(defvar Pk_F3 0xF0C0 t)
(defvar Pk_F4 0xF0C1 t)
(defvar Pk_F5 0xF0C2 t)
(defvar Pk_F6 0xF0C3 t)
(defvar Pk_F7 0xF0C4 t)
(defvar Pk_F8 0xF0C5 t)
(defvar Pk_F9 0xF0C6 t)
(defvar Pk_F10 0xF0C7 t)
(defvar Pk_F11 0xF0C8 t)
(defvar Pk_L1 0xF0C8 t)
(defvar Pk_F12 0xF0C9 t)
(defvar Pk_L2 0xF0C9 t)
(defvar Pk_F13 0xF0CA t)
(defvar Pk_L3 0xF0CA t)
(defvar Pk_F14 0xF0CB t)
(defvar Pk_L4 0xF0CB t)
(defvar Pk_F15 0xF0CC t)
(defvar Pk_L5 0xF0CC t)
(defvar Pk_F16 0xF0CD t)
(defvar Pk_L6 0xF0CD t)
(defvar Pk_F17 0xF0CE t)
(defvar Pk_L7 0xF0CE t)
(defvar Pk_F18 0xF0CF t)
(defvar Pk_L8 0xF0CF t)
(defvar Pk_F19 0xF0D0 t)
(defvar Pk_L9 0xF0D0 t)
(defvar Pk_F20 0xF0D1 t)
(defvar Pk_L10 0xF0D1 t)
(defvar Pk_F21 0xF0D2 t)
(defvar Pk_R1 0xF0D2 t)
(defvar Pk_F22 0xF0D3 t)
(defvar Pk_R2 0xF0D3 t)
(defvar Pk_F23 0xF0D4 t)
(defvar Pk_R3 0xF0D4 t)
(defvar Pk_F24 0xF0D5 t)
(defvar Pk_R4 0xF0D5 t)
(defvar Pk_F25 0xF0D6 t)
(defvar Pk_R5 0xF0D6 t)
(defvar Pk_F26 0xF0D7 t)
(defvar Pk_R6 0xF0D7 t)
(defvar Pk_F27 0xF0D8 t)
(defvar Pk_R7 0xF0D8 t)
(defvar Pk_F28 0xF0D9 t)
(defvar Pk_R8 0xF0D9 t)
(defvar Pk_F29 0xF0DA t)
(defvar Pk_R9 0xF0DA t)
(defvar Pk_F30 0xF0DB t)
(defvar Pk_R10 0xF0DB t)
(defvar Pk_F31 0xF0DC t)
(defvar Pk_R11 0xF0DC t)
(defvar Pk_F32 0xF0DD t)
(defvar Pk_R12 0xF0DD t)
(defvar Pk_F33 0xF0DE t)
(defvar Pk_R13 0xF0DE t)
(defvar Pk_F34 0xF0DF t)
(defvar Pk_R14 0xF0DF t)
(defvar Pk_F35 0xF0E0 t)
(defvar Pk_R15 0xF0E0 t)
(defvar Pk_Shift_L 0xF0E1 t)
(defvar Pk_Shift_R 0xF0E2 t)
(defvar Pk_Control_L 0xF0E3 t)
(defvar Pk_Control_R 0xF0E4 t)
(defvar Pk_Caps_Lock 0xF0E5 t)
(defvar Pk_Shift_Lock 0xF0E6 t)
(defvar Pk_Meta_L 0xF0E7 t)
(defvar Pk_Meta_R 0xF0E8 t)
(defvar Pk_Alt_L 0xF0E9 t)
(defvar Pk_Alt_R 0xF0EA t)
(defvar Pk_Super_L 0xF0EB t)
(defvar Pk_Super_R 0xF0EC t)
(defvar Pk_Hyper_L 0xF0ED t)
(defvar Pk_Hyper_R 0xF0EE t)
(defvar Pk_space 0x020 t)
(defvar Pk_exclam 0x021 t)
(defvar Pk_quotedbl 0x022 t)
(defvar Pk_numbersign 0x023 t)
(defvar Pk_dollar 0x024 t)
(defvar Pk_percent 0x025 t)
(defvar Pk_ampersand 0x026 t)
(defvar Pk_apostrophe 0x027 t)
(defvar Pk_quoteright 0x027 t)
(defvar Pk_parenleft 0x028 t)
(defvar Pk_parenright 0x029 t)
(defvar Pk_asterisk 0x02a t)
(defvar Pk_plus 0x02b t)
(defvar Pk_comma 0x02c t)
(defvar Pk_minus 0x02d t)
(defvar Pk_period 0x02e t)
(defvar Pk_slash 0x02f t)
(defvar Pk_0 0x030 t)
(defvar Pk_1 0x031 t)
(defvar Pk_2 0x032 t)
(defvar Pk_3 0x033 t)
(defvar Pk_4 0x034 t)
(defvar Pk_5 0x035 t)
(defvar Pk_6 0x036 t)
(defvar Pk_7 0x037 t)
(defvar Pk_8 0x038 t)
(defvar Pk_9 0x039 t)
(defvar Pk_colon 0x03a t)
(defvar Pk_semicolon 0x03b t)
(defvar Pk_less 0x03c t)
(defvar Pk_equal 0x03d t)
(defvar Pk_greater 0x03e t)
(defvar Pk_question 0x03f t)
(defvar Pk_at 0x040 t)
(defvar Pk_A 0x041 t)
(defvar Pk_B 0x042 t)
(defvar Pk_C 0x043 t)
(defvar Pk_D 0x044 t)
(defvar Pk_E 0x045 t)
(defvar Pk_F 0x046 t)
(defvar Pk_G 0x047 t)
(defvar Pk_H 0x048 t)
(defvar Pk_I 0x049 t)
(defvar Pk_J 0x04a t)
(defvar Pk_K 0x04b t)
(defvar Pk_L 0x04c t)
(defvar Pk_M 0x04d t)
(defvar Pk_N 0x04e t)
(defvar Pk_O 0x04f t)
(defvar Pk_P 0x050 t)
(defvar Pk_Q 0x051 t)
(defvar Pk_R 0x052 t)
(defvar Pk_S 0x053 t)
(defvar Pk_T 0x054 t)
(defvar Pk_U 0x055 t)
(defvar Pk_V 0x056 t)
(defvar Pk_W 0x057 t)
(defvar Pk_X 0x058 t)
(defvar Pk_Y 0x059 t)
(defvar Pk_Z 0x05a t)
(defvar Pk_bracketleft 0x05b t)
(defvar Pk_backslash 0x05c t)
(defvar Pk_bracketright 0x05d t)
(defvar Pk_asciicircum 0x05e t)
(defvar Pk_carrot 0x05e t)
(defvar Pk_underscore 0x05f t)
(defvar Pk_grave 0x060 t)
(defvar Pk_quoteleft 0x060 t)
(defvar Pk_a 0x061 t)
(defvar Pk_b 0x062 t)
(defvar Pk_c 0x063 t)
(defvar Pk_d 0x064 t)
(defvar Pk_e 0x065 t)
(defvar Pk_f 0x066 t)
(defvar Pk_g 0x067 t)
(defvar Pk_h 0x068 t)
(defvar Pk_i 0x069 t)
(defvar Pk_j 0x06a t)
(defvar Pk_k 0x06b t)
(defvar Pk_l 0x06c t)
(defvar Pk_m 0x06d t)
(defvar Pk_n 0x06e t)
(defvar Pk_o 0x06f t)
(defvar Pk_p 0x070 t)
(defvar Pk_q 0x071 t)
(defvar Pk_r 0x072 t)
(defvar Pk_s 0x073 t)
(defvar Pk_t 0x074 t)
(defvar Pk_u 0x075 t)
(defvar Pk_v 0x076 t)
(defvar Pk_w 0x077 t)
(defvar Pk_x 0x078 t)
(defvar Pk_y 0x079 t)
(defvar Pk_z 0x07a t)
(defvar Pk_braceleft 0x07b t)
(defvar Pk_bar 0x07c t)
(defvar Pk_braceright 0x07d t)
(defvar Pk_asciitilde 0x07e t)
(defvar Pk_nobreakspace 0x0a0 t)
(defvar Pk_exclamdown 0x0a1 t)
(defvar Pk_cent 0x0a2 t)
(defvar Pk_sterling 0x0a3 t)
(defvar Pk_currency 0x0a4 t)
(defvar Pk_yen 0x0a5 t)
(defvar Pk_brokenbar 0x0a6 t)
(defvar Pk_section 0x0a7 t)
(defvar Pk_diaeresis 0x0a8 t)
(defvar Pk_copyright 0x0a9 t)
(defvar Pk_ordfeminine 0x0aa t)
(defvar Pk_guillemotleft 0x0ab t)
(defvar Pk_notsign 0x0ac t)
(defvar Pk_hyphen 0x0ad t)
(defvar Pk_registered 0x0ae t)
(defvar Pk_macron 0x0af t)
(defvar Pk_degree 0x0b0 t)
(defvar Pk_plusminus 0x0b1 t)
(defvar Pk_twosuperior 0x0b2 t)
(defvar Pk_threesuperior 0x0b3 t)
(defvar Pk_acute 0x0b4 t)
(defvar Pk_mu 0x0b5 t)
(defvar Pk_paragraph 0x0b6 t)
(defvar Pk_periodcentered 0x0b7 t)
(defvar Pk_cedilla 0x0b8 t)
(defvar Pk_onesuperior 0x0b9 t)
(defvar Pk_masculine 0x0ba t)
(defvar Pk_guillemotright 0x0bb t)
(defvar Pk_onequarter 0x0bc t)
(defvar Pk_onehalf 0x0bd t)
(defvar Pk_threequarters 0x0be t)
(defvar Pk_questiondown 0x0bf t)
(defvar Pk_Agrave 0x0c0 t)
(defvar Pk_Aacute 0x0c1 t)
(defvar Pk_Acircumflex 0x0c2 t)
(defvar Pk_Atilde 0x0c3 t)
(defvar Pk_Adiaeresis 0x0c4 t)
(defvar Pk_Aring 0x0c5 t)
(defvar Pk_AE 0x0c6 t)
(defvar Pk_Ccedilla 0x0c7 t)
(defvar Pk_Egrave 0x0c8 t)
(defvar Pk_Eacute 0x0c9 t)
(defvar Pk_Ecircumflex 0x0ca t)
(defvar Pk_Ediaeresis 0x0cb t)
(defvar Pk_Igrave 0x0cc t)
(defvar Pk_Iacute 0x0cd t)
(defvar Pk_Icircumflex 0x0ce t)
(defvar Pk_Idiaeresis 0x0cf t)
(defvar Pk_ETH 0x0d0 t)
(defvar Pk_Eth 0x0d0 t)
(defvar Pk_Ntilde 0x0d1 t)
(defvar Pk_Ograve 0x0d2 t)
(defvar Pk_Oacute 0x0d3 t)
(defvar Pk_Ocircumflex 0x0d4 t)
(defvar Pk_Otilde 0x0d5 t)
(defvar Pk_Odiaeresis 0x0d6 t)
(defvar Pk_multiply 0x0d7 t)
(defvar Pk_Ooblique 0x0d8 t)
(defvar Pk_Ugrave 0x0d9 t)
(defvar Pk_Uacute 0x0da t)
(defvar Pk_Ucircumflex 0x0db t)
(defvar Pk_Udiaeresis 0x0dc t)
(defvar Pk_Yacute 0x0dd t)
(defvar Pk_THORN 0x0de t)
(defvar Pk_Thorn 0x0de t)
(defvar Pk_ssharp 0x0df t)
(defvar Pk_agrave 0x0e0 t)
(defvar Pk_aacute 0x0e1 t)
(defvar Pk_acircumflex 0x0e2 t)
(defvar Pk_atilde 0x0e3 t)
(defvar Pk_adiaeresis 0x0e4 t)
(defvar Pk_aring 0x0e5 t)
(defvar Pk_ae 0x0e6 t)
(defvar Pk_ccedilla 0x0e7 t)
(defvar Pk_egrave 0x0e8 t)
(defvar Pk_eacute 0x0e9 t)
(defvar Pk_ecircumflex 0x0ea t)
(defvar Pk_ediaeresis 0x0eb t)
(defvar Pk_igrave 0x0ec t)
(defvar Pk_iacute 0x0ed t)
(defvar Pk_icircumflex 0x0ee t)
(defvar Pk_idiaeresis 0x0ef t)
(defvar Pk_eth 0x0f0 t)
(defvar Pk_ntilde 0x0f1 t)
(defvar Pk_ograve 0x0f2 t)
(defvar Pk_oacute 0x0f3 t)
(defvar Pk_ocircumflex 0x0f4 t)
(defvar Pk_otilde 0x0f5 t)
(defvar Pk_odiaeresis 0x0f6 t)
(defvar Pk_division 0x0f7 t)
(defvar Pk_oslash 0x0f8 t)
(defvar Pk_ugrave 0x0f9 t)
(defvar Pk_uacute 0x0fa t)
(defvar Pk_ucircumflex 0x0fb t)
(defvar Pk_udiaeresis 0x0fc t)
(defvar Pk_yacute 0x0fd t)
(defvar Pk_thorn 0x0fe t)
(defvar Pk_ydiaeresis 0x0ff t)
(defvar Pk_Amacron 0x0100 t)
(defvar Pk_amacron 0x0101 t)
(defvar Pk_Abreve 0x0102 t)
(defvar Pk_abreve 0x0103 t)
(defvar Pk_Aogonek 0x0104 t)
(defvar Pk_aogonek 0x0105 t)
(defvar Pk_Cacute 0x0106 t)
(defvar Pk_cacute 0x0107 t)
(defvar Pk_Ccircumflex 0x0108 t)
(defvar Pk_ccircumflex 0x0109 t)
(defvar Pk_Cabovedot 0x010A t)
(defvar Pk_cabovedot 0x010B t)
(defvar Pk_Ccaron 0x010C t)
(defvar Pk_ccaron 0x010D t)
(defvar Pk_Dcaron 0x010E t)
(defvar Pk_dcaron 0x010F t)
(defvar Pk_Dstroke 0x0110 t)
(defvar Pk_dstroke 0x0111 t)
(defvar Pk_Emacron 0x0112 t)
(defvar Pk_emacron 0x0113 t)
(defvar Pk_Ebreve 0x0114 t)
(defvar Pk_ebreve 0x0115 t)
(defvar Pk_Eabovedot 0x0116 t)
(defvar Pk_eabovedot 0x0117 t)
(defvar Pk_Eogonek 0x0118 t)
(defvar Pk_eogonek 0x0119 t)
(defvar Pk_Ecaron 0x011A t)
(defvar Pk_ecaron 0x011B t)
(defvar Pk_Gcircumflex 0x011C t)
(defvar Pk_gcircumflex 0x011D t)
(defvar Pk_Gbreve 0x011E t)
(defvar Pk_gbreve 0x011F t)
(defvar Pk_Gabovedot 0x0120 t)
(defvar Pk_gabovedot 0x0121 t)
(defvar Pk_Gcedilla 0x0122 t)
(defvar Pk_gcedilla 0x0123 t)
(defvar Pk_Hcircumflex 0x0124 t)
(defvar Pk_hcircumflex 0x0125 t)
(defvar Pk_Hstroke 0x0126 t)
(defvar Pk_hstroke 0x0127 t)
(defvar Pk_Itilde 0x0128 t)
(defvar Pk_itilde 0x0129 t)
(defvar Pk_Imacron 0x012A t)
(defvar Pk_imacron 0x012B t)
(defvar Pk_Ibreve 0x012C t)
(defvar Pk_ibreve 0x012D t)
(defvar Pk_Iogonek 0x012E t)
(defvar Pk_iogonek 0x012F t)
(defvar Pk_Iabovedot 0x0130 t)
(defvar Pk_idotless 0x0131 t)
(defvar Pk_IJ 0x0132 t)
(defvar Pk_ij 0x0133 t)
(defvar Pk_Jcircumflex 0x0134 t)
(defvar Pk_jcircumflex 0x0135 t)
(defvar Pk_Kcedilla 0x0136 t)
(defvar Pk_kcedilla 0x0137 t)
(defvar Pk_kra 0x0138 t)
(defvar Pk_Lacute 0x0139 t)
(defvar Pk_lacute 0x013A t)
(defvar Pk_Lcedilla 0x013B t)
(defvar Pk_lcedilla 0x013C t)
(defvar Pk_Lcaron 0x013D t)
(defvar Pk_lcaron 0x013E t)
(defvar Pk_Lmiddledot 0x013F t)
(defvar Pk_lmiddledot 0x0140 t)
(defvar Pk_Lstroke 0x0141 t)
(defvar Pk_lstroke 0x0142 t)
(defvar Pk_Nacute 0x0143 t)
(defvar Pk_nacute 0x0144 t)
(defvar Pk_Ncedilla 0x0145 t)
(defvar Pk_ncedilla 0x0146 t)
(defvar Pk_Ncaron 0x0147 t)
(defvar Pk_ncaron 0x0148 t)
(defvar Pk_napostrophe 0x0149 t)
(defvar Pk_ENG 0x014A t)
(defvar Pk_eng 0x014B t)
(defvar Pk_Omacron 0x014C t)
(defvar Pk_omacron 0x014D t)
(defvar Pk_Obreve 0x014E t)
(defvar Pk_obreve 0x014F t)
(defvar Pk_Odoubleacute 0x0150 t)
(defvar Pk_odoubleacute 0x0151 t)
(defvar Pk_OE 0x0152 t)
(defvar Pk_oe 0x0153 t)
(defvar Pk_Racute 0x0154 t)
(defvar Pk_racute 0x0155 t)
(defvar Pk_Rcedilla 0x0156 t)
(defvar Pk_rcedilla 0x0157 t)
(defvar Pk_Rcaron 0x0158 t)
(defvar Pk_rcaron 0x0159 t)
(defvar Pk_Sacute 0x015A t)
(defvar Pk_sacute 0x015B t)
(defvar Pk_Scircumflex 0x015C t)
(defvar Pk_scircumflex 0x015D t)
(defvar Pk_Scedilla 0x015E t)
(defvar Pk_scedilla 0x015F t)
(defvar Pk_Scaron 0x0160 t)
(defvar Pk_scaron 0x0161 t)
(defvar Pk_Tcedilla 0x0162 t)
(defvar Pk_tcedilla 0x0163 t)
(defvar Pk_Tcaron 0x0164 t)
(defvar Pk_tcaron 0x0165 t)
(defvar Pk_Tstroke 0x0166 t)
(defvar Pk_tstroke 0x0167 t)
(defvar Pk_Utilde 0x0168 t)
(defvar Pk_utilde 0x0169 t)
(defvar Pk_Umacron 0x016A t)
(defvar Pk_umacron 0x016B t)
(defvar Pk_Ubreve 0x016C t)
(defvar Pk_ubreve 0x016D t)
(defvar Pk_Uringabove 0x016E t)
(defvar Pk_uringabove 0x016F t)
(defvar Pk_Udoubleacute 0x0170 t)
(defvar Pk_udoubleacute 0x0171 t)
(defvar Pk_Uogonek 0x0172 t)
(defvar Pk_uogonek 0x0173 t)
(defvar Pk_Wcircumflex 0x0174 t)
(defvar Pk_wcircumflex 0x0175 t)
(defvar Pk_Ycircumflex 0x0176 t)
(defvar Pk_ycircumflex 0x0177 t)
(defvar Pk_Ydiaeresis 0x0178 t)
(defvar Pk_Zacute 0x0179 t)
(defvar Pk_zacute 0x017A t)
(defvar Pk_Zabovedot 0x017B t)
(defvar Pk_zabovedot 0x017C t)
(defvar Pk_Zcaron 0x017D t)
(defvar Pk_zcaron 0x017E t)
(defvar Pk_slong 0x017F t)
(defvar Pk_bstroke 0x0180 t)
(defvar Pk_Bhook 0x0181 t)
(defvar Pk_Btopbar 0x0182 t)
(defvar Pk_btopbar 0x0183 t)
(defvar Pk_ToneSix 0x0184 t)
(defvar Pk_tonesix 0x0185 t)
(defvar Pk_Oopen 0x0186 t)
(defvar Pk_Chook 0x0187 t)
(defvar Pk_chook 0x0188 t)
(defvar Pk_Dafrican 0x0189 t)
(defvar Pk_Dhook 0x018A t)
(defvar Pk_Dtopbar 0x018B t)
(defvar Pk_dtopbar 0x018C t)
(defvar Pk_turneddelta 0x018D t)
(defvar Pk_ereversed 0x018E t)
(defvar Pk_SCHWA 0x018F t)
(defvar Pk_Eopen 0x0190 t)
(defvar Pk_Fhook 0x0191 t)
(defvar Pk_fhook 0x0192 t)
(defvar Pk_Ghook 0x0193 t)
(defvar Pk_GAMMA 0x0194 t)
(defvar Pk_hv 0x0195 t)
(defvar Pk_IOTA 0x0196 t)
(defvar Pk_Istroke 0x0197 t)
(defvar Pk_Khook 0x0198 t)
(defvar Pk_khook 0x0199 t)
(defvar Pk_lbar 0x019A t)
(defvar Pk_lambdastroke 0x019B t)
(defvar Pk_Mturned 0x019C t)
(defvar Pk_Nlefthook 0x019D t)
(defvar Pk_nlongrightleg 0x019E t)
(defvar Pk_Omiddletilde 0x019F t)
(defvar Pk_Ohorn 0x01A0 t)
(defvar Pk_ohorn 0x01A1 t)
(defvar Pk_OI 0x01A2 t)
(defvar Pk_oi 0x01A3 t)
(defvar Pk_Phook 0x01A4 t)
(defvar Pk_phook 0x01A5 t)
(defvar Pk_yr 0x01A6 t)
(defvar Pk_ToneTwo 0x01A7 t)
(defvar Pk_tonetwo 0x01A8 t)
(defvar Pk_ESH 0x01A9 t)
(defvar Pk_eshreversedloop 0x01AA t)
(defvar Pk_tpalatalhook 0x01AB t)
(defvar Pk_Thook 0x01AC t)
(defvar Pk_thook 0x01AD t)
(defvar Pk_Tretroflexhook 0x01AE t)
(defvar Pk_Uhorn 0x01AF t)
(defvar Pk_uhorn 0x01B0 t)
(defvar Pk_UPSILON 0x01B1 t)
(defvar Pk_Vhook 0x01B2 t)
(defvar Pk_Yhook 0x01B3 t)
(defvar Pk_yhook 0x01B4 t)
(defvar Pk_Zstroke 0x01B5 t)
(defvar Pk_zstroke 0x01B6 t)
(defvar Pk_EZH 0x01B7 t)
(defvar Pk_EZHreversed 0x01B8 t)
(defvar Pk_ezhreversed 0x01B9 t)
(defvar Pk_ezhtail 0x01BA t)
(defvar Pk_2stroke 0x01BB t)
(defvar Pk_ToneFive 0x01BC t)
(defvar Pk_tonefive 0x01BD t)
(defvar Pk_glottalstopinvertedstroke 0x01BE t)
(defvar Pk_wynn 0x01BF t)
(defvar Pk_dentalclick 0x01C0 t)
(defvar Pk_lateralclick 0x01C1 t)
(defvar Pk_alveolarclick 0x01C2 t)
(defvar Pk_retroflexclick 0x01C3 t)
(defvar Pk_DZcaron 0x01C4 t)
(defvar Pk_Dzcaron 0x01C5 t)
(defvar Pk_dzcaron 0x01C6 t)
(defvar Pk_LJ 0x01C7 t)
(defvar Pk_Lj 0x01C8 t)
(defvar Pk_lj 0x01C9 t)
(defvar Pk_NJ 0x01CA t)
(defvar Pk_Nj 0x01CB t)
(defvar Pk_nj 0x01CC t)
(defvar Pk_Acaron 0x01CD t)
(defvar Pk_acaron 0x01CE t)
(defvar Pk_Icaron 0x01CF t)
(defvar Pk_icaron 0x01D0 t)
(defvar Pk_Ocaron 0x01D1 t)
(defvar Pk_ocaron 0x01D2 t)
(defvar Pk_Ucaron 0x01D3 t)
(defvar Pk_ucaron 0x01D4 t)
(defvar Pk_Udiaeresismacron 0x01D5 t)
(defvar Pk_udiaeresismacron 0x01D6 t)
(defvar Pk_Udiaeresisacute 0x01D7 t)
(defvar Pk_udiaeresisacute 0x01D8 t)
(defvar Pk_Udiaeresiscaron 0x01D9 t)
(defvar Pk_udiaeresiscaron 0x01DA t)
(defvar Pk_Udiaeresisgrave 0x01DB t)
(defvar Pk_udiaeresisgrave 0x01DC t)
(defvar Pk_eturned 0x01DD t)
(defvar Pk_Adiaeresismacron 0x01DE t)
(defvar Pk_adiaeresismacron 0x01DF t)
(defvar Pk_Aabovedotmacron 0x01E0 t)
(defvar Pk_aabovedotmacron 0x01E1 t)
(defvar Pk_AEmacron 0x01E2 t)
(defvar Pk_aemacron 0x01E3 t)
(defvar Pk_Gstroke 0x01E4 t)
(defvar Pk_gstroke 0x01E5 t)
(defvar Pk_Gcaron 0x01E6 t)
(defvar Pk_gcaron 0x01E7 t)
(defvar Pk_Kcaron 0x01E8 t)
(defvar Pk_kcaron 0x01E9 t)
(defvar Pk_Oogonek 0x01EA t)
(defvar Pk_oogonek 0x01EB t)
(defvar Pk_Oogonekmacron 0x01EC t)
(defvar Pk_oogonekmacron 0x01ED t)
(defvar Pk_EZHcaron 0x01EE t)
(defvar Pk_ezhcaron 0x01EF t)
(defvar Pk_jcaron 0x01F0 t)
(defvar Pk_DZ 0x01F1 t)
(defvar Pk_Dz 0x01F2 t)
(defvar Pk_dz 0x01F3 t)
(defvar Pk_Gacute 0x01F4 t)
(defvar Pk_gacute 0x01F5 t)
(defvar Pk_Aaboveringacute 0x01FA t)
(defvar Pk_aaboveringacute 0x01FB t)
(defvar Pk_AEacute 0x01FC t)
(defvar Pk_aeacute 0x01FD t)
(defvar Pk_Ostrokeacute 0x01FE t)
(defvar Pk_ostrokeacute 0x01FF t)
(defvar Pk_Adoublegrave 0x0200 t)
(defvar Pk_adoublegrave 0x0201 t)
(defvar Pk_Ainvertedbreve 0x0202 t)
(defvar Pk_ainvertedbreve 0x0203 t)
(defvar Pk_Edoublegrave 0x0204 t)
(defvar Pk_edoublegrave 0x0205 t)
(defvar Pk_Einvertedbreve 0x0206 t)
(defvar Pk_einvertedbreve 0x0207 t)
(defvar Pk_Idoublegrave 0x0208 t)
(defvar Pk_idoublegrave 0x0209 t)
(defvar Pk_Iinvertedbreve 0x020A t)
(defvar Pk_iinvertedbreve 0x020B t)
(defvar Pk_Odoublegrave 0x020C t)
(defvar Pk_odoublegrave 0x020D t)
(defvar Pk_Oinvertedbreve 0x020E t)
(defvar Pk_oinvertedbreve 0x020F t)
(defvar Pk_Rdoublegrave 0x0210 t)
(defvar Pk_rdoublegrave 0x0211 t)
(defvar Pk_Rinvertedbreve 0x0212 t)
(defvar Pk_rinvertedbreve 0x0213 t)
(defvar Pk_Udoublegrave 0x0214 t)
(defvar Pk_udoublegrave 0x0215 t)
(defvar Pk_Uinvertedbreve 0x0216 t)
(defvar Pk_uinvertedbreve 0x0217 t)
(defvar Pk_combining_grave 0x0300 t)
(defvar Pk_combining_acute 0x0301 t)
(defvar Pk_combining_circumflex 0x0302 t)
(defvar Pk_combining_tilde 0x0303 t)
(defvar Pk_combining_macron 0x0304 t)
(defvar Pk_combining_overline 0x0305 t)
(defvar Pk_combining_breve 0x0306 t)
(defvar Pk_combining_abovedot 0x0307 t)
(defvar Pk_combining_diaeresis 0x0308 t)
(defvar Pk_combining_abovehook 0x0309 t)
(defvar Pk_combining_abovering 0x030A t)
(defvar Pk_combining_doubleacute 0x030B t)
(defvar Pk_combining_caron 0x030C t)
(defvar Pk_combining_aboveverticalline 0x030D t)
(defvar Pk_combining_abovedoubleverticalline 0x030E t)
(defvar Pk_combining_doublegrave 0x030F t)
(defvar Pk_combining_candrabindu 0x0310 t)
(defvar Pk_combining_invertedbreve 0x0311 t)
(defvar Pk_combining_aboveturnedcomma 0x0312 t)
(defvar Pk_combining_abovecomma 0x0313 t)
(defvar Pk_combining_abovereversedcomma 0x0314 t)
(defvar Pk_combining_aboverightcomma 0x0315 t)
(defvar Pk_combining_belowgrave 0x0316 t)
(defvar Pk_combining_belowacute 0x0317 t)
(defvar Pk_combining_belowlefttack 0x0318 t)
(defvar Pk_combining_belowrighttack 0x0319 t)
(defvar Pk_combining_aboveleftangle 0x031A t)
(defvar Pk_combining_horn 0x031B t)
(defvar Pk_combining_belowlefthalfring 0x031C t)
(defvar Pk_combining_belowuptack 0x031D t)
(defvar Pk_combining_belowdowntack 0x031E t)
(defvar Pk_combining_belowplus 0x031F t)
(defvar Pk_combining_belowminus 0x0320 t)
(defvar Pk_combining_belowpalatalizedhook 0x0321 t)
(defvar Pk_combining_belowretroflexhook 0x0322 t)
(defvar Pk_combining_belowdot 0x0323 t)
(defvar Pk_combining_belowdiaeresis 0x0324 t)
(defvar Pk_combining_belowring 0x0325 t)
(defvar Pk_combining_belowcomma 0x0326 t)
(defvar Pk_combining_cedilla 0x0327 t)
(defvar Pk_combining_ogonek 0x0328 t)
(defvar Pk_combining_belowverticalline 0x0329 t)
(defvar Pk_combining_belowbridge 0x032A t)
(defvar Pk_combining_belowdoublearch 0x032B t)
(defvar Pk_combining_belowcaron 0x032C t)
(defvar Pk_combining_belowcircumflex 0x032D t)
(defvar Pk_combining_belowbreve 0x032E t)
(defvar Pk_combining_belowinvertedbreve 0x032F t)
(defvar Pk_combining_belowtilde 0x0330 t)
(defvar Pk_combining_belowmacron 0x0331 t)
(defvar Pk_combining_lowline 0x0332 t)
(defvar Pk_combining_doublelowline 0x0333 t)
(defvar Pk_combining_overlaytilde 0x0334 t)
(defvar Pk_combining_overlayshortstroke 0x0335 t)
(defvar Pk_combining_overlaylongstroke 0x0336 t)
(defvar Pk_combining_overlaysolidusshort 0x0337 t)
(defvar Pk_combining_slashshort 0x0337 t)
(defvar Pk_combining_overlaysoliduslong 0x0338 t)
(defvar Pk_combining_slashlong 0x0338 t)
(defvar Pk_combining_belowrighthalfring 0x0339 t)
(defvar Pk_combining_belowinvertedbridge 0x033A t)
(defvar Pk_combining_belowsquare 0x033B t)
(defvar Pk_combining_belowseagull 0x033C t)
(defvar Pk_combining_abovex 0x033D t)
(defvar Pk_combining_verticaltilde 0x033E t)
(defvar Pk_combining_doubleoverline 0x033F t)
(defvar Pk_combining_gravetonemark 0x0340 t)
(defvar Pk_combining_acutetonemark 0x0341 t)
(defvar Pk_combining_perispomeni 0x0342 t)
(defvar Pk_combining_koronis 0x0343 t)
(defvar Pk_combining_dialytikatonos 0x0344 t)
(defvar Pk_combining_ypogegrammeni 0x0345 t)
(defvar Pk_combining_doubletilde 0x0360 t)
(defvar Pk_combining_doubleinvertedbreve 0x0361 t)
(defvar Pk_Greek_numeralsign 0x0374 t)
(defvar Pk_Greek_lowernumeralsign 0x0375 t)
(defvar Pk_Greek_ypogegrammeni 0x037A t)
(defvar Pk_Greek_questionmark 0x037E t)
(defvar Pk_Greek_tonos 0x0384 t)
(defvar Pk_Greek_accent 0x0384 t)
(defvar Pk_Greek_tonosdialytika 0x0385 t)
(defvar Pk_Greek_accentdieresis 0x0385 t)
(defvar Pk_Greek_ALPHAtonos 0x0386 t)
(defvar Pk_Greek_ALPHAaccent 0x0386 t)
(defvar Pk_Greek_ano_teleia 0x0387 t)
(defvar Pk_Greek_EPSILONtonos 0x0388 t)
(defvar Pk_Greek_EPSILONaccent 0x0388 t)
(defvar Pk_Greek_ETAtonos 0x0389 t)
(defvar Pk_Greek_ETAaccent 0x0389 t)
(defvar Pk_Greek_IOTAtonos 0x038A t)
(defvar Pk_Greek_IOTAaccent 0x038A t)
(defvar Pk_Greek_OMICRONtonos 0x038C t)
(defvar Pk_Greek_OMICRONaccent 0x038C t)
(defvar Pk_Greek_UPSILONtonos 0x038E t)
(defvar Pk_Greek_UPSILONaccent 0x038E t)
(defvar Pk_Greek_OMEGAtonos 0x038F t)
(defvar Pk_Greek_OMEGAaccent 0x038F t)
(defvar Pk_Greek_iotatonosdialytika 0x0390 t)
(defvar Pk_Greek_iotaaccentdieresis 0x0390 t)
(defvar Pk_Greek_ALPHA 0x0391 t)
(defvar Pk_Greek_BETA 0x0392 t)
(defvar Pk_Greek_GAMMA 0x0393 t)
(defvar Pk_Greek_DELTA 0x0394 t)
(defvar Pk_Greek_EPSILON 0x0395 t)
(defvar Pk_Greek_ZETA 0x0396 t)
(defvar Pk_Greek_ETA 0x0397 t)
(defvar Pk_Greek_THETA 0x0398 t)
(defvar Pk_Greek_IOTA 0x0399 t)
(defvar Pk_Greek_KAPPA 0x039A t)
(defvar Pk_Greek_LAMDA 0x039B t)
(defvar Pk_Greek_LAMBDA 0x039B t)
(defvar Pk_Greek_MU 0x039C t)
(defvar Pk_Greek_NU 0x039D t)
(defvar Pk_Greek_XI 0x039E t)
(defvar Pk_Greek_OMICRON 0x039F t)
(defvar Pk_Greek_PI 0x03A0 t)
(defvar Pk_Greek_RHO 0x03A1 t)
(defvar Pk_Greek_SIGMA 0x03A3 t)
(defvar Pk_Greek_TAU 0x03A4 t)
(defvar Pk_Greek_UPSILON 0x03A5 t)
(defvar Pk_Greek_PHI 0x03A6 t)
(defvar Pk_Greek_CHI 0x03A7 t)
(defvar Pk_Greek_PSI 0x03A8 t)
(defvar Pk_Greek_OMEGA 0x03A9 t)
(defvar Pk_Greek_IOTAdiaeresis 0x03AA t)
(defvar Pk_Greek_UPSILONdialytika 0x03AB t)
(defvar Pk_Greek_UPSILONdieresis 0x03AB t)
(defvar Pk_Greek_alphatonos 0x03AC t)
(defvar Pk_Greek_alphaaccent 0x03AC t)
(defvar Pk_Greek_epsilontonos 0x03AD t)
(defvar Pk_Greek_epsilonaccent 0x03AD t)
(defvar Pk_Greek_etatonos 0x03AE t)
(defvar Pk_Greek_etaaccent 0x03AE t)
(defvar Pk_Greek_iotatonos 0x03AF t)
(defvar Pk_Greek_iotaaccent 0x03AF t)
(defvar Pk_Greek_upsilontonosdialytika 0x03B0 t)
(defvar Pk_Greek_upsilonaccentdieresis 0x03B0 t)
(defvar Pk_Greek_alpha 0x03B1 t)
(defvar Pk_Greek_beta 0x03B2 t)
(defvar Pk_Greek_gamma 0x03B3 t)
(defvar Pk_Greek_delta 0x03B4 t)
(defvar Pk_Greek_epsilon 0x03B5 t)
(defvar Pk_Greek_zeta 0x03B6 t)
(defvar Pk_Greek_eta 0x03B7 t)
(defvar Pk_Greek_theta 0x03B8 t)
(defvar Pk_Greek_iota 0x03B9 t)
(defvar Pk_Greek_kappa 0x03BA t)
(defvar Pk_Greek_lamda 0x03BB t)
(defvar Pk_Greek_lambda 0x03BB t)
(defvar Pk_Greek_mu 0x03BC t)
(defvar Pk_Greek_nu 0x03BD t)
(defvar Pk_Greek_xi 0x03BE t)
(defvar Pk_Greek_omicron 0x03BF t)
(defvar Pk_Greek_pi 0x03C0 t)
(defvar Pk_Greek_rho 0x03C1 t)
(defvar Pk_Greek_finalsigma 0x03C2 t)
(defvar Pk_Greek_finalsmallsigma 0x03C2 t)
(defvar Pk_Greek_sigma 0x03C3 t)
(defvar Pk_Greek_tau 0x03C4 t)
(defvar Pk_Greek_upsilon 0x03C5 t)
(defvar Pk_Greek_phi 0x03C6 t)
(defvar Pk_Greek_chi 0x03C7 t)
(defvar Pk_Greek_psi 0x03C8 t)
(defvar Pk_Greek_omega 0x03C9 t)
(defvar Pk_Greek_iotadialytika 0x03CA t)
(defvar Pk_Greek_iotadieresis 0x03CA t)
(defvar Pk_Greek_upsilondialytika 0x03CB t)
(defvar Pk_Greek_upsilondieresis 0x03CB t)
(defvar Pk_Greek_omicrontonos 0x03CC t)
(defvar Pk_Greek_omicronaccent 0x03CC t)
(defvar Pk_Greek_upsilontonos 0x03CD t)
(defvar Pk_Greek_upsilonaccent 0x03CD t)
(defvar Pk_Greek_omegatonos 0x03CE t)
(defvar Pk_Greek_omegaaccent 0x03CE t)
(defvar Pk_Greek_switch 0xF07E t)
(defvar Pk_Cyrillic_IO 0x0401 t)
(defvar Pk_Cyrillic_DJE 0x0402 t)
(defvar Pk_Serbian_DJE 0x0402 t)
(defvar Pk_Macedonia_GJE 0x0403 t)
(defvar Pk_Ukrainian_IE 0x0404 t)
(defvar Pk_Cyrillic_DZE 0x0405 t)
(defvar Pk_Byelorussian_Ukrainian_I 0x0406 t)
(defvar Pk_Ukrainian_I 0x0406 t)
(defvar Pk_Cyrillic_YI 0x0407 t)
(defvar Pk_Ukrainian_YI 0x0407 t)
(defvar Pk_Cyrillic_JE 0x0408 t)
(defvar Pk_Cyrillic_LJE 0x0409 t)
(defvar Pk_Cyrillic_NJE 0x040A t)
(defvar Pk_Cyrillic_TSHE 0x040B t)
(defvar Pk_Serbian_TSHE 0x040B t)
(defvar Pk_Cyrillic_KJE 0x040C t)
(defvar Pk_Macedonia_KJE 0x040C t)
(defvar Pk_Cyrillic_SHORTU 0x040E t)
(defvar Pk_Byelorussian_SHORTU 0x040E t)
(defvar Pk_Cyrillic_DZHE 0x040F t)
(defvar Pk_Cyrillic_A 0x0410 t)
(defvar Pk_Cyrillic_BE 0x0411 t)
(defvar Pk_Cyrillic_VE 0x0412 t)
(defvar Pk_Cyrillic_GHE 0x0413 t)
(defvar Pk_Cyrillic_DE 0x0414 t)
(defvar Pk_Cyrillic_IE 0x0415 t)
(defvar Pk_Cyrillic_ZHE 0x0416 t)
(defvar Pk_Cyrillic_ZE 0x0417 t)
(defvar Pk_Cyrillic_I 0x0418 t)
(defvar Pk_Cyrillic_SHORTI 0x0419 t)
(defvar Pk_Cyrillic_KA 0x041A t)
(defvar Pk_Cyrillic_EL 0x041B t)
(defvar Pk_Cyrillic_EM 0x041C t)
(defvar Pk_Cyrillic_EN 0x041D t)
(defvar Pk_Cyrillic_O 0x041E t)
(defvar Pk_Cyrillic_PE 0x041F t)
(defvar Pk_Cyrillic_ER 0x0420 t)
(defvar Pk_Cyrillic_ES 0x0421 t)
(defvar Pk_Cyrillic_TE 0x0422 t)
(defvar Pk_Cyrillic_U 0x0423 t)
(defvar Pk_Cyrillic_EF 0x0424 t)
(defvar Pk_Cyrillic_HA 0x0425 t)
(defvar Pk_Cyrillic_TSE 0x0426 t)
(defvar Pk_Cyrillic_CHE 0x0427 t)
(defvar Pk_Cyrillic_SHA 0x0428 t)
(defvar Pk_Cyrillic_SHCHA 0x0429 t)
(defvar Pk_Cyrillic_HARDSIGN 0x042A t)
(defvar Pk_Cyrillic_YERU 0x042B t)
(defvar Pk_Cyrillic_SOFTSIGN 0x042C t)
(defvar Pk_Cyrillic_E 0x042D t)
(defvar Pk_Cyrillic_YU 0x042E t)
(defvar Pk_Cyrillic_YA 0x042F t)
(defvar Pk_Cyrillic_a 0x0430 t)
(defvar Pk_Cyrillic_be 0x0431 t)
(defvar Pk_Cyrillic_ve 0x0432 t)
(defvar Pk_Cyrillic_ghe 0x0433 t)
(defvar Pk_Cyrillic_de 0x0434 t)
(defvar Pk_Cyrillic_ie 0x0435 t)
(defvar Pk_Cyrillic_zhe 0x0436 t)
(defvar Pk_Cyrillic_ze 0x0437 t)
(defvar Pk_Cyrillic_i 0x0438 t)
(defvar Pk_Cyrillic_shorti 0x0439 t)
(defvar Pk_Cyrillic_ka 0x043A t)
(defvar Pk_Cyrillic_el 0x043B t)
(defvar Pk_Cyrillic_em 0x043C t)
(defvar Pk_Cyrillic_en 0x043D t)
(defvar Pk_Cyrillic_o 0x043E t)
(defvar Pk_Cyrillic_pe 0x043F t)
(defvar Pk_Cyrillic_er 0x0440 t)
(defvar Pk_Cyrillic_es 0x0441 t)
(defvar Pk_Cyrillic_te 0x0442 t)
(defvar Pk_Cyrillic_u 0x0443 t)
(defvar Pk_Cyrillic_ef 0x0444 t)
(defvar Pk_Cyrillic_ha 0x0445 t)
(defvar Pk_Cyrillic_tse 0x0446 t)
(defvar Pk_Cyrillic_che 0x0447 t)
(defvar Pk_Cyrillic_sha 0x0448 t)
(defvar Pk_Cyrillic_shcha 0x0449 t)
(defvar Pk_Cyrillic_hardsign 0x044A t)
(defvar Pk_Cyrillic_yeru 0x044B t)
(defvar Pk_Cyrillic_softsign 0x044C t)
(defvar Pk_Cyrillic_e 0x044D t)
(defvar Pk_Cyrillic_yu 0x044E t)
(defvar Pk_Cyrillic_ya 0x044F t)
(defvar Pk_Cyrillic_io 0x0451 t)
(defvar Pk_Cyrillic_dje 0x0452 t)
(defvar Pk_Serbian_dje 0x0452 t)
(defvar Pk_Cyrillic_gje 0x0453 t)
(defvar Pk_Macedonia_gje 0x0453 t)
(defvar Pk_Ukrainian_ie 0x0454 t)
(defvar Pk_Cyrillic_dze 0x0455 t)
(defvar Pk_Byelorussian_Ukrainian_i 0x0456 t)
(defvar Pk_Ukrainian_i 0x0456 t)
(defvar Pk_Cyrillic_yi 0x0457 t)
(defvar Pk_Ukrainian_yi 0x0457 t)
(defvar Pk_Cyrillic_je 0x0458 t)
(defvar Pk_Cyrillic_lje 0x0459 t)
(defvar Pk_Cyrillic_nje 0x045A t)
(defvar Pk_Cyrillic_tshe 0x045B t)
(defvar Pk_Serbian_tshe 0x045B t)
(defvar Pk_Cyrillic_kje 0x045C t)
(defvar Pk_Macedonia_kje 0x045C t)
(defvar Pk_Cyrillic_shortu 0x045E t)
(defvar Pk_Byelorussian_shortu 0x045E t)
(defvar Pk_Cyrillic_dzhe 0x045F t)
(defvar Pk_Cyrillic_OMEGA 0x0460 t)
(defvar Pk_Cyrillic_omega 0x0461 t)
(defvar Pk_Cyrillic_YAT 0x0462 t)
(defvar Pk_Cyrillic_yat 0x0463 t)
(defvar Pk_Cyrillic_Eiotified 0x0464 t)
(defvar Pk_Cyrillic_eiotified 0x0465 t)
(defvar Pk_Cyrillic_YUS 0x0466 t)
(defvar Pk_Cyrillic_yus 0x0467 t)
(defvar Pk_Cyrillic_YUSiotifiedlittle 0x0468 t)
(defvar Pk_Cyrillic_yusiotifiedlittle 0x0469 t)
(defvar Pk_Cyrillic_YUSbig 0x046A t)
(defvar Pk_Cyrillic_yusbig 0x046B t)
(defvar Pk_Cyrillic_YUSiotifiedbig 0x046C t)
(defvar Pk_Cyrillic_yusiotifiedbig 0x046D t)
(defvar Pk_Cyrillic_KSI 0x046E t)
(defvar Pk_Cyrillic_ksi 0x046F t)
(defvar Pk_Cyrillic_PSI 0x0470 t)
(defvar Pk_Cyrillic_psi 0x0471 t)
(defvar Pk_Cyrillic_FITA 0x0472 t)
(defvar Pk_Cyrillic_fita 0x0473 t)
(defvar Pk_Cyrillic_IZHITSA 0x0474 t)
(defvar Pk_Cyrillic_izhitsa 0x0475 t)
(defvar Pk_Cyrillic_IZHITSAdoublegrave 0x0476 t)
(defvar Pk_Cyrillic_izhitsadoublegrave 0x0477 t)
(defvar Pk_Cyrillic_UK 0x0478 t)
(defvar Pk_Cyrillic_uk 0x0479 t)
(defvar Pk_Cyrillic_OMEGAround 0x047A t)
(defvar Pk_Cyrillic_omegaround 0x047B t)
(defvar Pk_Cyrillic_OMEGAtitlo 0x047C t)
(defvar Pk_Cyrillic_omegatitlo 0x047D t)
(defvar Pk_Cyrillic_OT 0x047E t)
(defvar Pk_Cyrillic_ot 0x047F t)
(defvar Pk_Hebrew_sheva 0x05B0 t)
(defvar Pk_Hebrew_hatafsegol 0x05B1 t)
(defvar Pk_Hebrew_hatafpatah 0x05B2 t)
(defvar Pk_Hebrew_hatafqamats 0x05B3 t)
(defvar Pk_Hebrew_hiriq 0x05B4 t)
(defvar Pk_Hebrew_tsere 0x05B5 t)
(defvar Pk_Hebrew_segol 0x05B6 t)
(defvar Pk_Hebrew_patah 0x05B7 t)
(defvar Pk_Hebrew_qamats 0x05B8 t)
(defvar Pk_Hebrew_holam 0x05B9 t)
(defvar Pk_Hebrew_qubuts 0x05BB t)
(defvar Pk_Hebrew_dageshormapiq 0x05BC t)
(defvar Pk_Hebrew_meteg 0x05BD t)
(defvar Pk_Hebrew_maqaf 0x05BE t)
(defvar Pk_Hebrew_rafe 0x05BF t)
(defvar Pk_Hebrew_paseq 0x05C0 t)
(defvar Pk_Hebrew_shindot 0x05C1 t)
(defvar Pk_Hebrew_sindot 0x05C2 t)
(defvar Pk_Hebrew_sofpasuq 0x05C3 t)
(defvar Pk_Hebrew_aleph 0x05D0 t)
(defvar Pk_Hebrew_bet 0x05D1 t)
(defvar Pk_Hebrew_beth 0x05D1 t)
(defvar Pk_Hebrew_gimel 0x05D2 t)
(defvar Pk_Hebrew_gimmel 0x05D2 t)
(defvar Pk_Hebrew_dalet 0x05D3 t)
(defvar Pk_Hebrew_daleth 0x05D3 t)
(defvar Pk_Hebrew_he 0x05D4 t)
(defvar Pk_Hebrew_waw 0x05D5 t)
(defvar Pk_Hebrew_vav 0x05D5 t)
(defvar Pk_Hebrew_zayin 0x05D6 t)
(defvar Pk_Hebrew_zain 0x05D6 t)
(defvar Pk_Hebrew_het 0x05D7 t)
(defvar Pk_Hebrew_chet 0x05D7 t)
(defvar Pk_Hebrew_tet 0x05D8 t)
(defvar Pk_Hebrew_teth 0x05D8 t)
(defvar Pk_Hebrew_yod 0x05D9 t)
(defvar Pk_Hebrew_finalkaf 0x05DA t)
(defvar Pk_Hebrew_finalkaph 0x05DA t)
(defvar Pk_Hebrew_kaf 0x05DB t)
(defvar Pk_Hebrew_kaph 0x05DB t)
(defvar Pk_Hebrew_lamed 0x05DC t)
(defvar Pk_Hebrew_finalmem 0x05DD t)
(defvar Pk_Hebrew_mem 0x05DE t)
(defvar Pk_Hebrew_finalnun 0x05DF t)
(defvar Pk_Hebrew_nun 0x05E0 t)
(defvar Pk_Hebrew_samekh 0x05E1 t)
(defvar Pk_Hebrew_samech 0x05E1 t)
(defvar Pk_Hebrew_ayin 0x05E2 t)
(defvar Pk_Hebrew_finalpe 0x05E3 t)
(defvar Pk_Hebrew_pe 0x05E4 t)
(defvar Pk_Hebrew_finaltsadi 0x05E5 t)
(defvar Pk_Hebrew_finalzade 0x05E5 t)
(defvar Pk_Hebrew_finalzadi 0x05E5 t)
(defvar Pk_Hebrew_tsadi 0x05E6 t)
(defvar Pk_Hebrew_zade 0x05E6 t)
(defvar Pk_Hebrew_zadi 0x05E6 t)
(defvar Pk_Hebrew_qof 0x05E7 t)
(defvar Pk_Hebrew_qoph 0x05E7 t)
(defvar Pk_Hebrew_kuf 0x05E7 t)
(defvar Pk_Hebrew_resh 0x05E8 t)
(defvar Pk_Hebrew_shin 0x05E9 t)
(defvar Pk_Hebrew_tav 0x05EA t)
(defvar Pk_Hebrew_taw 0x05EA t)
(defvar Pk_Hebrew_taf 0x05EA t)
(defvar Pk_Yiddish_double_vav 0x05F0 t)
(defvar Pk_Yiddish_vav_yod 0x05F1 t)
(defvar Pk_Yiddish_double_yod 0x05F2 t)
(defvar Pk_Hebrew_geresh 0x05F3 t)
(defvar Pk_Hebrew_gershayim 0x05F4 t)
(defvar Pk_Hebrew_switch 0xF07E t)
(defvar Pk_Arabic_comma 0x060C t)
(defvar Pk_Arabic_semicolon 0x061B t)
(defvar Pk_Arabic_question_mark 0x061F t)
(defvar Pk_Arabic_hamza 0x0621 t)
(defvar Pk_Arabic_maddaonalef 0x0622 t)
(defvar Pk_Arabic_hamzaonalef 0x0623 t)
(defvar Pk_Arabic_hamzaonwaw 0x0624 t)
(defvar Pk_Arabic_hamzaunderalef 0x0625 t)
(defvar Pk_Arabic_hamzaonyeh 0x0626 t)
(defvar Pk_Arabic_alef 0x0627 t)
(defvar Pk_Arabic_beh 0x0628 t)
(defvar Pk_Arabic_tehmarbuta 0x0629 t)
(defvar Pk_Arabic_teh 0x062A t)
(defvar Pk_Arabic_theh 0x062B t)
(defvar Pk_Arabic_jeem 0x062C t)
(defvar Pk_Arabic_hah 0x062D t)
(defvar Pk_Arabic_khah 0x062E t)
(defvar Pk_Arabic_dal 0x062F t)
(defvar Pk_Arabic_thal 0x0630 t)
(defvar Pk_Arabic_ra 0x0631 t)
(defvar Pk_Arabic_zain 0x0632 t)
(defvar Pk_Arabic_seen 0x0633 t)
(defvar Pk_Arabic_sheen 0x0634 t)
(defvar Pk_Arabic_sad 0x0635 t)
(defvar Pk_Arabic_dad 0x0636 t)
(defvar Pk_Arabic_tah 0x0637 t)
(defvar Pk_Arabic_zah 0x0638 t)
(defvar Pk_Arabic_ain 0x0639 t)
(defvar Pk_Arabic_ghain 0x063A t)
(defvar Pk_Arabic_tatweel 0x0640 t)
(defvar Pk_Arabic_feh 0x0641 t)
(defvar Pk_Arabic_qaf 0x0642 t)
(defvar Pk_Arabic_kaf 0x0643 t)
(defvar Pk_Arabic_lam 0x0644 t)
(defvar Pk_Arabic_meem 0x0645 t)
(defvar Pk_Arabic_noon 0x0646 t)
(defvar Pk_Arabic_heh 0x0647 t)
(defvar Pk_Arabic_ha 0x0647 t)
(defvar Pk_Arabic_waw 0x0648 t)
(defvar Pk_Arabic_alefmaksura 0x0649 t)
(defvar Pk_Arabic_yeh 0x064A t)
(defvar Pk_Arabic_fathatan 0x064B t)
(defvar Pk_Arabic_dammatan 0x064C t)
(defvar Pk_Arabic_kasratan 0x064D t)
(defvar Pk_Arabic_fatha 0x064E t)
(defvar Pk_Arabic_damma 0x064F t)
(defvar Pk_Arabic_kasra 0x0650 t)
(defvar Pk_Arabic_shadda 0x0651 t)
(defvar Pk_Arabic_sukun 0x0652 t)
(defvar Pk_Arabic_switch 0xF07E t)
(defvar Pk_overline 0x47e t)
(defvar Pk_kana_fullstop 0xff61 t)
(defvar Pk_kana_openingbracket 0xff62 t)
(defvar Pk_kana_closingbracket 0xff63 t)
(defvar Pk_kana_comma 0xff64 t)
(defvar Pk_kana_conjunctive 0xff65 t)
(defvar Pk_kana_middledot 0xff65 t)
(defvar Pk_kana_WO 0xff66 t)
(defvar Pk_kana_a 0xff67 t)
(defvar Pk_kana_i 0xff68 t)
(defvar Pk_kana_u 0xff69 t)
(defvar Pk_kana_e 0xff6a t)
(defvar Pk_kana_o 0xff6b t)
(defvar Pk_kana_ya 0xff6c t)
(defvar Pk_kana_yu 0xff6d t)
(defvar Pk_kana_yo 0xff6e t)
(defvar Pk_kana_tsu 0xff6f t)
(defvar Pk_kana_tu 0xff6f t)
(defvar Pk_prolongedsound 0xff70 t)
(defvar Pk_kana_A 0xff71 t)
(defvar Pk_kana_I 0xff72 t)
(defvar Pk_kana_U 0xff73 t)
(defvar Pk_kana_E 0xff74 t)
(defvar Pk_kana_O 0xff75 t)
(defvar Pk_kana_KA 0xff76 t)
(defvar Pk_kana_KI 0xff77 t)
(defvar Pk_kana_KU 0xff78 t)
(defvar Pk_kana_KE 0xff79 t)
(defvar Pk_kana_KO 0xff7a t)
(defvar Pk_kana_SA 0xff7b t)
(defvar Pk_kana_SHI 0xff7c t)
(defvar Pk_kana_SU 0xff7d t)
(defvar Pk_kana_SE 0xff7e t)
(defvar Pk_kana_SO 0xff7f t)
(defvar Pk_kana_TA 0xff80 t)
(defvar Pk_kana_CHI 0xff81 t)
(defvar Pk_kana_TI 0xff81 t)
(defvar Pk_kana_TSU 0xff82 t)
(defvar Pk_kana_TU 0xff82 t)
(defvar Pk_kana_TE 0xff83 t)
(defvar Pk_kana_TO 0xff84 t)
(defvar Pk_kana_NA 0xff85 t)
(defvar Pk_kana_NI 0xff86 t)
(defvar Pk_kana_NU 0xff87 t)
(defvar Pk_kana_NE 0xff88 t)
(defvar Pk_kana_NO 0xff89 t)
(defvar Pk_kana_HA 0xff8a t)
(defvar Pk_kana_HI 0xff8b t)
(defvar Pk_kana_FU 0xff8c t)
(defvar Pk_kana_HU 0xff8c t)
(defvar Pk_kana_HE 0xff8d t)
(defvar Pk_kana_HO 0xff8e t)
(defvar Pk_kana_MA 0xff8f t)
(defvar Pk_kana_MI 0xff90 t)
(defvar Pk_kana_MU 0xff91 t)
(defvar Pk_kana_ME 0xff92 t)
(defvar Pk_kana_MO 0xff93 t)
(defvar Pk_kana_YA 0xff94 t)
(defvar Pk_kana_YU 0xff95 t)
(defvar Pk_kana_YO 0xff96 t)
(defvar Pk_kana_RA 0xff97 t)
(defvar Pk_kana_RI 0xff98 t)
(defvar Pk_kana_RU 0xff99 t)
(defvar Pk_kana_RE 0xff9a t)
(defvar Pk_kana_RO 0xff9b t)
(defvar Pk_kana_WA 0xff9c t)
(defvar Pk_kana_N 0xff9d t)
(defvar Pk_voicedsound 0xff9e t)
(defvar Pk_semivoicedsound 0xff9f t)
(defvar Pk_kana_switch 0xF07E t)
(defvar Pk_leftradical 0x8a1 t)
(defvar Pk_topleftradical 0x8a2 t)
(defvar Pk_horizconnector 0x8a3 t)
(defvar Pk_topintegral 0x8a4 t)
(defvar Pk_botintegral 0x8a5 t)
(defvar Pk_vertconnector 0x8a6 t)
(defvar Pk_topleftsqbracket 0x8a7 t)
(defvar Pk_botleftsqbracket 0x8a8 t)
(defvar Pk_toprightsqbracket 0x8a9 t)
(defvar Pk_botrightsqbracket 0x8aa t)
(defvar Pk_topleftparens 0x8ab t)
(defvar Pk_botleftparens 0x8ac t)
(defvar Pk_toprightparens 0x8ad t)
(defvar Pk_botrightparens 0x8ae t)
(defvar Pk_leftmiddlecurlybrace 0x8af t)
(defvar Pk_rightmiddlecurlybrace 0x8b0 t)
(defvar Pk_topleftsummation 0x8b1 t)
(defvar Pk_botleftsummation 0x8b2 t)
(defvar Pk_topvertsummationconnector 0x8b3 t)
(defvar Pk_botvertsummationconnector 0x8b4 t)
(defvar Pk_toprightsummation 0x8b5 t)
(defvar Pk_botrightsummation 0x8b6 t)
(defvar Pk_rightmiddlesummation 0x8b7 t)
(defvar Pk_lessthanequal 0x8bc t)
(defvar Pk_notequal 0x8bd t)
(defvar Pk_greaterthanequal 0x8be t)
(defvar Pk_integral 0x8bf t)
(defvar Pk_therefore 0x8c0 t)
(defvar Pk_variation 0x8c1 t)
(defvar Pk_infinity 0x8c2 t)
(defvar Pk_nabla 0x8c5 t)
(defvar Pk_approximate 0x8c8 t)
(defvar Pk_similarequal 0x8c9 t)
(defvar Pk_ifonlyif 0x8cd t)
(defvar Pk_implies 0x8ce t)
(defvar Pk_identical 0x8cf t)
(defvar Pk_radical 0x8d6 t)
(defvar Pk_includedin 0x8da t)
(defvar Pk_includes 0x8db t)
(defvar Pk_intersection 0x8dc t)
(defvar Pk_union 0x8dd t)
(defvar Pk_logicaland 0x8de t)
(defvar Pk_logicalor 0x8df t)
(defvar Pk_partialderivative 0x8ef t)
(defvar Pk_function 0x8f6 t)
(defvar Pk_leftarrow 0x8fb t)
(defvar Pk_uparrow 0x8fc t)
(defvar Pk_rightarrow 0x8fd t)
(defvar Pk_downarrow 0x8fe t)
(defvar Pk_blank 0x9df t)
(defvar Pk_soliddiamond 0x9e0 t)
(defvar Pk_checkerboard 0x9e1 t)
(defvar Pk_ht 0x9e2 t)
(defvar Pk_ff 0x9e3 t)
(defvar Pk_cr 0x9e4 t)
(defvar Pk_lf 0x9e5 t)
(defvar Pk_nl 0x9e8 t)
(defvar Pk_vt 0x9e9 t)
(defvar Pk_lowrightcorner 0x9ea t)
(defvar Pk_uprightcorner 0x9eb t)
(defvar Pk_upleftcorner 0x9ec t)
(defvar Pk_lowleftcorner 0x9ed t)
(defvar Pk_crossinglines 0x9ee t)
(defvar Pk_horizlinescan1 0x9ef t)
(defvar Pk_horizlinescan3 0x9f0 t)
(defvar Pk_horizlinescan5 0x9f1 t)
(defvar Pk_horizlinescan7 0x9f2 t)
(defvar Pk_horizlinescan9 0x9f3 t)
(defvar Pk_leftt 0x9f4 t)
(defvar Pk_rightt 0x9f5 t)
(defvar Pk_bott 0x9f6 t)
(defvar Pk_topt 0x9f7 t)
(defvar Pk_vertbar 0x9f8 t)
(defvar Pk_emspace 0xaa1 t)
(defvar Pk_enspace 0xaa2 t)
(defvar Pk_em3space 0xaa3 t)
(defvar Pk_em4space 0xaa4 t)
(defvar Pk_digitspace 0xaa5 t)
(defvar Pk_punctspace 0xaa6 t)
(defvar Pk_thinspace 0xaa7 t)
(defvar Pk_hairspace 0xaa8 t)
(defvar Pk_emdash 0xaa9 t)
(defvar Pk_endash 0xaaa t)
(defvar Pk_signifblank 0xaac t)
(defvar Pk_ellipsis 0xaae t)
(defvar Pk_doubbaselinedot 0xaaf t)
(defvar Pk_onethird 0xab0 t)
(defvar Pk_twothirds 0xab1 t)
(defvar Pk_onefifth 0xab2 t)
(defvar Pk_twofifths 0xab3 t)
(defvar Pk_threefifths 0xab4 t)
(defvar Pk_fourfifths 0xab5 t)
(defvar Pk_onesixth 0xab6 t)
(defvar Pk_fivesixths 0xab7 t)
(defvar Pk_careof 0xab8 t)
(defvar Pk_figdash 0xabb t)
(defvar Pk_leftanglebracket 0xabc t)
(defvar Pk_decimalpoint 0xabd t)
(defvar Pk_rightanglebracket 0xabe t)
(defvar Pk_marker 0xabf t)
(defvar Pk_oneeighth 0xac3 t)
(defvar Pk_threeeighths 0xac4 t)
(defvar Pk_fiveeighths 0xac5 t)
(defvar Pk_seveneighths 0xac6 t)
(defvar Pk_trademark 0xac9 t)
(defvar Pk_signaturemark 0xaca t)
(defvar Pk_trademarkincircle 0xacb t)
(defvar Pk_leftopentriangle 0xacc t)
(defvar Pk_rightopentriangle 0xacd t)
(defvar Pk_emopencircle 0xace t)
(defvar Pk_emopenrectangle 0xacf t)
(defvar Pk_leftsinglequotemark 0xad0 t)
(defvar Pk_rightsinglequotemark 0xad1 t)
(defvar Pk_leftdoublequotemark 0xad2 t)
(defvar Pk_rightdoublequotemark 0xad3 t)
(defvar Pk_prescription 0xad4 t)
(defvar Pk_minutes 0xad6 t)
(defvar Pk_seconds 0xad7 t)
(defvar Pk_latincross 0xad9 t)
(defvar Pk_hexagram 0xada t)
(defvar Pk_filledrectbullet 0xadb t)
(defvar Pk_filledlefttribullet 0xadc t)
(defvar Pk_filledrighttribullet 0xadd t)
(defvar Pk_emfilledcircle 0xade t)
(defvar Pk_emfilledrect 0xadf t)
(defvar Pk_enopencircbullet 0xae0 t)
(defvar Pk_enopensquarebullet 0xae1 t)
(defvar Pk_openrectbullet 0xae2 t)
(defvar Pk_opentribulletup 0xae3 t)
(defvar Pk_opentribulletdown 0xae4 t)
(defvar Pk_openstar 0xae5 t)
(defvar Pk_enfilledcircbullet 0xae6 t)
(defvar Pk_enfilledsqbullet 0xae7 t)
(defvar Pk_filledtribulletup 0xae8 t)
(defvar Pk_filledtribulletdown 0xae9 t)
(defvar Pk_leftpointer 0xaea t)
(defvar Pk_rightpointer 0xaeb t)
(defvar Pk_club 0xaec t)
(defvar Pk_diamond 0xaed t)
(defvar Pk_heart 0xaee t)
(defvar Pk_maltesecross 0xaf0 t)
(defvar Pk_dagger 0xaf1 t)
(defvar Pk_doubledagger 0xaf2 t)
(defvar Pk_checkmark 0xaf3 t)
(defvar Pk_ballotcross 0xaf4 t)
(defvar Pk_musicalsharp 0xaf5 t)
(defvar Pk_musicalflat 0xaf6 t)
(defvar Pk_malesymbol 0xaf7 t)
(defvar Pk_femalesymbol 0xaf8 t)
(defvar Pk_telephone 0xaf9 t)
(defvar Pk_telephonerecorder 0xafa t)
(defvar Pk_phonographcopyright 0xafb t)
(defvar Pk_caret 0xafc t)
(defvar Pk_singlelowquotemark 0xafd t)
(defvar Pk_doublelowquotemark 0xafe t)
(defvar Pk_cursor 0xaff t)
(defvar Pk_leftcaret 0xba3 t)
(defvar Pk_rightcaret 0xba6 t)
(defvar Pk_downcaret 0xba8 t)
(defvar Pk_upcaret 0xba9 t)
(defvar Pk_overbar 0xbc0 t)
(defvar Pk_downtack 0xbc2 t)
(defvar Pk_upshoe 0xbc3 t)
(defvar Pk_downstile 0xbc4 t)
(defvar Pk_underbar 0xbc6 t)
(defvar Pk_jot 0xbca t)
(defvar Pk_quad 0xbcc t)
(defvar Pk_uptack 0xbce t)
(defvar Pk_circle 0xbcf t)
(defvar Pk_upstile 0xbd3 t)
(defvar Pk_downshoe 0xbd6 t)
(defvar Pk_rightshoe 0xbd8 t)
(defvar Pk_leftshoe 0xbda t)
(defvar Pk_lefttack 0xbdc t)
(defvar Pk_righttack 0xbfc t)
